@@ -23,6 +23,7 @@
 
 #include <QList>
 #include <QAction>
+#include <QFileInfo>
 #include <QWidget>
 #include <QVariantList>
 #include <QUrl>
@@ -52,18 +53,14 @@ TagsFileItemAction::TagsFileItemAction(QObject* parent, const QVariantList&)
             action->setCheckable(true);
             action->setChecked(m_metaData->tags().contains(name));
 
-            connect(action, &QAction::triggered, this, [this, action] {
-                if (action->isChecked()) {
-                    QStringList newTags = m_metaData->tags();
-                    // HACK the first character of QAction::text is '&'
-                    newTags.append(action->text().remove(0,1));
-                    m_metaData->setTags(newTags);
+            connect(action, &QAction::triggered, this, [this, name](bool isChecked) {
+                QStringList newTags = m_metaData->tags();
+                if (isChecked) {
+                    newTags.append(name);
                 } else {
-                    QStringList newTags = m_metaData->tags();
-                    // HACK the first character of QAction::text is '&'
-                    newTags.removeAll(action->text().remove(0,1));
-                    m_metaData->setTags(newTags);
+                    newTags.removeAll(name);
                 }
+                m_metaData->setTags(newTags);
             });
         }
     });
@@ -74,8 +71,10 @@ TagsFileItemAction::TagsFileItemAction(QObject* parent, const QVariantList&)
     connect(newAction, &QAction::triggered, this, [this] {
         QString newTag = QInputDialog::getText(m_menu, i18n("New tag"), i18n("New tag:"), QLineEdit::Normal);
         QStringList tags = m_metaData->tags();
-        tags.append(newTag);
-        m_metaData->setTags(tags);
+        if (!tags.contains(newTag)) {
+            tags.append(newTag);
+            m_metaData->setTags(tags);
+        }
     });
 
     m_menu->addAction(newAction);
@@ -96,7 +95,16 @@ QList<QAction*> TagsFileItemAction::actions(const KFileItemListProperties& fileI
         return {};
     }
 
-    m_metaData = new KFileMetaData::UserMetaData(fileItemInfos.urlList()[0].toLocalFile());
+    QString filePath = fileItemInfos.urlList()[0].toLocalFile();
+    if (!QFileInfo(filePath).isWritable()) {
+        return {};
+    }
+
+    m_metaData = new KFileMetaData::UserMetaData(filePath);
+    if (!m_metaData->isSupported()) {
+        return {};
+    }
+
     m_tagsLister.openUrl(QUrl("tags:/"), KCoreDirLister::OpenUrlFlag::Reload);
 
     return {m_menu->menuAction()};
